#ifndef _ACLOGGER_H
#define _ACLOGGER_H

#include "config.h"
#include "meta.h"

namespace aclog {

      bool open();
      void close();
      void reopen();
      void transfer(bool bDirIn, uint64_t nCount, const char *szClient, const char *szPath);
      void err(const char *msg, const char *client=NULL);
      inline void err(const MYSTD::string msg) { err(msg.c_str()); }
      void flush();
      
      void GenerateReport(MYSTD::string &);
      typedef struct {
      	time_t from, to;
      	double count, ratioSent;
      } tRowData;

      void GetStats(MYSTD::vector<tRowData> & out);
}

#define TIMEFORMAT "%a %d/%m"

#endif


